Index: source/PatParser.cpp
===================================================================
--- source/PatParser.cpp	(revision 27757)
+++ source/PatParser.cpp	(working copy)
@@ -99,7 +99,8 @@
 	for (itChannels it=m_mapChannels.begin(); it !=m_mapChannels.end();++it)
   {
 		CChannelInfo& info=it->second;
-		if (!info.PmtReceived || !info.SdtReceived) 
+		// Running status of 4 = "service running" (see EN300468)
+		if ((!info.PmtReceived && info.RunningStatus == 4) || !info.SdtReceived) 
 		{
 			//LogDebug("ch:%d pmt:%d sdt:%d othermux:%d %s onid:%x tsid:%x sid:%x",
 			//	x,info.PmtReceived,info.SdtReceived,info.OtherMux,info.ServiceName,
@@ -179,26 +180,49 @@
 //*****************************************************************************
 void CPatParser::OnSdtReceived(const CChannelInfo& sdtInfo)
 {
-	itChannels it=m_mapChannels.find(sdtInfo.ServiceId);
+	itChannels it = m_mapChannels.find(sdtInfo.ServiceId);
 
-	// check if we really have a channel with this sid
-  if (it==m_mapChannels.end()) return;
+  // Check if we already have a channel with this SID.
+  // If not, it is because the PMT hasn't yet been
+  // received. Note that we don't want to add information
+  // for "other" transport streams.
+  if (it == m_mapChannels.end() && !sdtInfo.OtherMux)
+  {
+    m_tickCount = GetTickCount();
 
-  CChannelInfo& info=it->second;
+    // Create a new channel.
+    CChannelInfo info;
+    info.NetworkId = sdtInfo.NetworkId;
+    info.TransportId = sdtInfo.TransportId;
+    info.ServiceId = sdtInfo.ServiceId;
+    info.FreeCAMode = sdtInfo.FreeCAMode;
+    info.RunningStatus = sdtInfo.RunningStatus;
+    info.ServiceType = sdtInfo.ServiceType;
+    info.OtherMux = sdtInfo.OtherMux;
+    strcpy(info.ProviderName, sdtInfo.ProviderName);
+    strcpy(info.ServiceName, sdtInfo.ServiceName);
+    info.PmtReceived = false;
+    info.SdtReceived = true;
+    m_mapChannels[sdtInfo.ServiceId] = info;
+    return;
+  }
 
-	// check if we already set the sdt for this channel
-	if (info.SdtReceived) return;
+  CChannelInfo& info = it->second;
 
-	m_tickCount = GetTickCount();
-	info.NetworkId=sdtInfo.NetworkId;
-	info.TransportId=sdtInfo.TransportId;
-	info.ServiceId=sdtInfo.ServiceId;
-	info.FreeCAMode=sdtInfo.FreeCAMode;
-	info.ServiceType=sdtInfo.ServiceType;
-	info.OtherMux=sdtInfo.OtherMux;
-	info.SdtReceived=true;
-	strcpy(info.ProviderName,sdtInfo.ProviderName);
-	strcpy(info.ServiceName,sdtInfo.ServiceName);
+  // check if we already set the sdt for this channel
+  if (info.SdtReceived) return;
+
+  m_tickCount = GetTickCount();
+  info.NetworkId = sdtInfo.NetworkId;
+  info.TransportId = sdtInfo.TransportId;
+  info.ServiceId = sdtInfo.ServiceId;
+  info.FreeCAMode = sdtInfo.FreeCAMode;
+  info.RunningStatus = sdtInfo.RunningStatus;
+  info.ServiceType = sdtInfo.ServiceType;
+  info.OtherMux = sdtInfo.OtherMux;
+  info.SdtReceived = true;
+  strcpy(info.ProviderName, sdtInfo.ProviderName);
+  strcpy(info.ServiceName, sdtInfo.ServiceName);
 }
 
 void CPatParser::OnPmtReceived2(int pid,int serviceId,int pcrPid,vector<PidInfo2> pidInfo)
Index: source/SdtParser.cpp
===================================================================
--- source/SdtParser.cpp	(revision 27757)
+++ source/SdtParser.cpp	(working copy)
@@ -101,6 +101,7 @@
 				info.TransportId=sections.table_id_extension;
         info.ServiceId=service_id;
         info.FreeCAMode=free_CA_mode;
+        info.RunningStatus=running_status;
 				info.OtherMux = (sections.table_id==0x46);
         if (m_pCallback!=NULL)
           m_pCallback->OnSdtReceived(info);
